six: Python 2 and 3 compatibility utilities
===========================================

Description
-----------

Python 2 and 3 compatibility utilities

License
-------

MIT License


Upstream Contact
----------------

- Author: Benjamin Peterson
- Home page: http://pypi.python.org/pypi/six/

Dependencies
------------

Python
